@@ -1,23 +1,8 @@
-/*
-* Copyright (C) 2019 ~ 2019 UnionTech Software Technology Co.,Ltd.
-*
-* Author:     liuyanga <liuyanga@uniontech.com>
-*
-* Maintainer: liuyanga <liuyanga@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2019 UnionTech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "folderselectdialog.h"
 #include "views/leftviewdelegate.h"
 #include "views/leftviewsortfilter.h"
@@ -396,6 +381,13 @@ void FolderSelectDialog::onFontChanged()
     m_noteInfo->setText(itemInfo);
 }
 
+void FolderSelectDialog::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() != Qt::Key_Up && event->key() != Qt::Key_Down) {
+        event->ignore();
+    }
+}
+
 /**
  * @brief FolderSelectDialog::getSelectIndex
  * @return 选中的记事本
