@@ -1,20 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Deepin Technology Co., Ltd.
-*
-* Author:     zhangteng <zhangteng@uniontech.com>
-* Maintainer: zhangteng <zhangteng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Deepin Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "ut_vnote2siconbutton.h"
 #include "vnote2siconbutton.h"
@@ -36,7 +23,7 @@ TEST_F(UT_VNote2SIconButton, UT_VNote2SIconButton_mouseReleaseEvent_001)
 {
     VNote2SIconButton vnote2siconbutton("test", "test");
     QPointF localPos;
-    QMouseEvent *event = new QMouseEvent(QEvent::MouseButtonPress, localPos, Qt::RightButton, Qt::RightButton, Qt::NoModifier);
+    QMouseEvent *event = new QMouseEvent(QEvent::MouseButtonPress, localPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
     int status = vnote2siconbutton.m_state;
     vnote2siconbutton.mouseReleaseEvent(event);
     EXPECT_TRUE(status != vnote2siconbutton.m_state);
